%define api		1.0
%define bname		gstreamer%{api}

%define build_plf	0

%if "%{?distro_section}" == "tainted"
%define build_plf	1
%endif

%define build_x264	0

%if %build_plf
%define build_x264	1
%endif

# disabled as we don't have hotdoc
%bcond_with docs

Summary:	GStreamer Streaming-media framework plug-ins
Name:		%{bname}-plugins-ugly
Version:	1.24.8
Release:	%mkrel 1
License:	LGPLv2+
Group:		Sound/Utilities
URL:		https://gstreamer.freedesktop.org/
Source:		https://gstreamer.freedesktop.org/src/gst-plugins-ugly/gst-plugins-ugly-%{version}.tar.xz
#gw for the pixbuf plugin
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(orc-0.4)
BuildRequires:	pkgconfig(gstreamer-plugins-base-1.0) >= %{version}
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(mad)
BuildRequires:	pkgconfig(id3tag)
BuildRequires:	pkgconfig(dvdread)
BuildRequires:	pkgconfig(check)
BuildRequires:	meson

%ifarch %{valgrind_arches} %{arm32}
BuildRequires:	pkgconfig(valgrind)
%endif

Provides:	%{bname}-audiosrc
Provides:	%{bname}-audiosink

%description
GStreamer is a streaming-media framework, based on graphs of filters which
operate on media data. Applications using this library can do anything
from real-time sound processing to playing videos, and just about anything
else media-related.  Its plugin-based architecture means that new data
types or processing capabilities can be added simply by installing new
plug-ins.

This package contains a set of plug-ins that have good quality and
correct functionality, but distributing them might pose problems. The
license on either the plug-ins or the supporting libraries might not
be how the GStreamer authors like. The code might be widely known to
present patent problems.

%if %build_plf
This package is in the 'tainted' section as it violates some patents.
%endif

%prep
%setup -q -n gst-plugins-ugly-%{version}

%build
%meson \
%if ! %build_x264
	-Dx264=disabled \
%endif
	-Ddoc=%{?with_docs:enabled}%{?!with_docs:disabled} \
	-Dtests=disabled \
	-Dpackage-name='%{_vendor} %{name} package' \
	-Dpackage-origin='https://www.%{_real_vendor}.org/' \
	-Dgpl=enabled

%meson_build

%check
%meson_test

%install
%meson_install

%find_lang gst-plugins-ugly-%{api}

%files -f gst-plugins-ugly-%{api}.lang
%license COPYING
%doc AUTHORS README.md NEWS
%{_libdir}/gstreamer-%{api}/libgstasf.so
%{_libdir}/gstreamer-%{api}/libgstdvdlpcmdec.so
%{_libdir}/gstreamer-%{api}/libgstdvdread.so
%{_libdir}/gstreamer-%{api}/libgstdvdsub.so
%{_libdir}/gstreamer-%{api}/libgstrealmedia.so

%if %build_x264
%package -n %{bname}-x264
Summary:	GStreamer plug-in for H264/AVC video encoding
Group:		Video/Utilities
BuildRequires:	pkgconfig(x264)

%description -n %{bname}-x264
Plug-in for encoding H264/AVC video.

This package is in the 'tainted' section as it violates some patents.
%files -n %{bname}-x264
%{_libdir}/gstreamer-%{api}/libgstx264.so
%{_datadir}/gstreamer-%{api}/presets/GstX264Enc.prs
%endif

### SIDPLAY ###
%package -n %{bname}-sid
Summary:	GStreamer Sid C64 music plugin
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:	sidplay-devel >= 1.36.0

%description -n %{bname}-sid
Plugin for playback of C64 SID format music files

%files -n %{bname}-sid
%{_libdir}/gstreamer-%{api}/libgstsid.so

### A52DEC ###
%package -n %{bname}-a52dec
Summary:	GStreamer AC-3 aka A/52 audio decoder plugin
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:	a52dec-devel >= 0.7.3

%description -n %{bname}-a52dec
Plugin for decoding of AC-3 (A/52) audio as often found on DVDs.

%files -n %{bname}-a52dec
%{_libdir}/gstreamer-%{api}/libgsta52dec.so

%package -n %{bname}-mpeg
Summary:	GStreamer plug-ins for MPEG video playback and encoding
Group:		Video/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:	libmpeg2dec-devel >= 0.3.1

%description -n %{bname}-mpeg
Plug-ins for playing and encoding MPEG video.

%files -n %{bname}-mpeg
%{_libdir}/gstreamer-%{api}/libgstmpeg2dec.so

%package -n %{bname}-cdio
Summary:	GStreamer plug-in for audio CD playback
Group:		Sound/Utilities
Requires:	%{bname}-plugins >= %{version}-%{release}
BuildRequires:	pkgconfig(libcdio)

%description -n %{bname}-cdio
Plug-in for audio CD playback.

%files -n %{bname}-cdio
%{_libdir}/gstreamer-%{api}/libgstcdio.so


%changelog
* Sun Oct 27 2024 wally <wally> 1.24.8-1.mga10
+ Revision: 2111387
- new version 1.24.8

* Fri Aug 30 2024 daviddavid <daviddavid> 1.24.7-1.mga10
+ Revision: 2092238
- new version: 1.24.7

* Fri Jun 07 2024 daviddavid <daviddavid> 1.24.4-1.mga10.tainted
+ Revision: 2070358
- new version: 1.24.4

* Mon Mar 25 2024 daviddavid <daviddavid> 1.24.1-1.mga10.tainted
+ Revision: 2052107
- new version 1.24.1

* Mon Mar 25 2024 daviddavid <daviddavid> 1.24.0-1.mga10
+ Revision: 2051916
- new version 1.24.0
- the AMR-NB and AMR-WB plugins have been moved from -ugly to -good

* Sun Feb 04 2024 wally <wally> 1.22.9-2.mga10.tainted
+ Revision: 2037168
- rebuild for arm32

* Mon Jan 29 2024 wally <wally> 1.22.9-1.mga10.tainted
+ Revision: 2036129
- new version 1.22.9

* Wed Dec 20 2023 ghibo <ghibo> 1.22.8-1.mga10.tainted
+ Revision: 2020053
- Update to release 1.22.8

* Mon Oct 09 2023 wally <wally> 1.22.6-1.mga10.tainted
+ Revision: 1993814
- new version 1.22.6

* Tue Aug 29 2023 ghibo <ghibo> 1.22.5-1.mga10
+ Revision: 1980859
- Update to release 1.22.5

* Sat Jul 08 2023 ghibo <ghibo> 1.22.4-1.mga9.tainted
+ Revision: 1963701
- Update to release 1.22.4

* Sun May 21 2023 ghibo <ghibo> 1.22.3-1.mga9
+ Revision: 1957545
- Update to release 1.22.3

* Tue Jan 24 2023 wally <wally> 1.22.0-1.mga9.tainted
+ Revision: 1935703
- new version 1.22.0

* Sat Jan 14 2023 wally <wally> 1.21.90-1.mga9.tainted
+ Revision: 1933046
- new version 1.21.90
- remove gstxingmux (moved to -good)

* Mon Dec 26 2022 wally <wally> 1.20.5-1.mga9.tainted
+ Revision: 1926957
- new version 1.20.5

* Sun Nov 20 2022 wally <wally> 1.20.4-1.mga9.tainted
+ Revision: 1909316
- new version 1.20.4

* Sat Jul 23 2022 wally <wally> 1.20.3-1.mga9.tainted
+ Revision: 1870398
- new version 1.20.3

* Sun May 08 2022 wally <wally> 1.20.2-1.mga9
+ Revision: 1856822
- new version 1.20.2

* Sun Apr 24 2022 wally <wally> 1.20.1-2.mga9
+ Revision: 1853027
- rebuild for x264 0.164

* Sun Apr 03 2022 wally <wally> 1.20.1-1.mga9.tainted
+ Revision: 1842431
- new version 1.20.1

* Sun Apr 03 2022 umeabot <umeabot> 1.18.5-2.mga9
+ Revision: 1841708
- Mageia 9 Mass Rebuild

* Sat Sep 18 2021 wally <wally> 1.18.5-1.mga9
+ Revision: 1745695
- new version 1.18.5 (mga#29452)

* Mon Apr 05 2021 wally <wally> 1.18.4-1.mga9.tainted
+ Revision: 1713703
- new version 1.18.4

* Mon Jan 18 2021 wally <wally> 1.18.3-1.mga8
+ Revision: 1672337
- new version 1.18.3

* Wed Dec 09 2020 wally <wally> 1.18.2-1.mga8
+ Revision: 1655023
- new version 1.18.2

* Sat Nov 21 2020 wally <wally> 1.18.1-1.mga8.tainted
+ Revision: 1648156
- new version 1.18.1
- drop old conflicts

* Sun Sep 13 2020 wally <wally> 1.18.0-1.mga8
+ Revision: 1625901
- new version 1.18.0

* Mon Jul 06 2020 daviddavid <daviddavid> 1.16.2-5.mga8
+ Revision: 1602630
- rebuild for new x264-0.157

* Wed Apr 22 2020 luigiwalser <luigiwalser> 1.16.2-4.mga8.tainted
+ Revision: 1571019
- rebuild for libdvdread

* Fri Mar 13 2020 daviddavid <daviddavid> 1.16.2-3.mga8
+ Revision: 1556012
- switch to meson build system (GStreamer has given up on autotools...)

* Tue Feb 18 2020 umeabot <umeabot> 1.16.2-2.mga8.tainted
+ Revision: 1539247
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Dec 04 2019 daviddavid <daviddavid> 1.16.2-1.mga8.tainted
+ Revision: 1464327
- new version 1.16.2

* Sun Nov 17 2019 daviddavid <daviddavid> 1.16.1-2.mga8
+ Revision: 1461381
- rebuild for new libdvdread 6.0.2

* Tue Sep 24 2019 daviddavid <daviddavid> 1.16.1-1.mga8
+ Revision: 1445542
- new version 1.16.1

* Sun Jul 14 2019 daviddavid <daviddavid> 1.16.0-2.mga8
+ Revision: 1421294
- rebuild for new libcdio 2.1.0

* Thu Apr 25 2019 wally <wally> 1.16.0-1.mga7.tainted
+ Revision: 1395335
- new version 1.16.0
- drop gst0.10 era and unapplied patch

* Sun Dec 30 2018 luigiwalser <luigiwalser> 1.14.4-2.mga7
+ Revision: 1347158
- rebuild for x264

* Fri Oct 05 2018 daviddavid <daviddavid> 1.14.4-1.mga7.tainted
+ Revision: 1317863
- new version 1.14.4

* Mon Sep 17 2018 daviddavid <daviddavid> 1.14.3-1.mga7.tainted
+ Revision: 1259436
- new version 1.14.3

* Sat Jul 21 2018 daviddavid <daviddavid> 1.14.2-1.mga7.tainted
+ Revision: 1244585
- new version: 1.14.2

* Mon May 21 2018 wally <wally> 1.14.1-1.mga7.tainted
+ Revision: 1231140
- new version 1.14.1

* Sat Apr 28 2018 daviddavid <daviddavid> 1.14.0-2.mga7
+ Revision: 1222994
- rebuild for new x264

* Sat Mar 24 2018 wally <wally> 1.14.0-1.mga7.tainted
+ Revision: 1212059
- use valgrind on every supported arch
- new version 1.14.0
- drop mpg123, lame and twolame moved to -good

* Sun Jan 14 2018 wally <wally> 1.12.4-2.mga7.tainted
+ Revision: 1193043
- rebuild for new libcdio

* Sat Dec 16 2017 wally <wally> 1.12.4-1.mga7.tainted
+ Revision: 1182808
- disable valgrind support on arm for now
- new version 1.12.4

* Tue Sep 26 2017 wally <wally> 1.12.3-1.mga7
+ Revision: 1159992
- new version 1.12.3

* Mon Jul 24 2017 wally <wally> 1.12.2-1.mga7.tainted
+ Revision: 1130356
- new version 1.12.2

* Fri May 05 2017 zezinho <zezinho> 1.10.3-2.mga6.tainted
+ Revision: 1099210
- mp3 patents gone

* Fri Feb 10 2017 ns80 <ns80> 1.10.3-1.mga6.tainted
+ Revision: 1085493
- new version 1.10.3

* Sat Jan 21 2017 akien <akien> 1.10.2-2.mga6.tainted
+ Revision: 1082724
- Rebuild for arm

* Sun Jan 15 2017 wally <wally> 1.10.2-1.mga6
+ Revision: 1081797
- new version 1.10.2

* Mon Aug 22 2016 akien <akien> 1.8.3-3.mga6.tainted
+ Revision: 1047860
- Submit to tainted

* Mon Aug 22 2016 daviddavid <daviddavid> 1.8.3-2.mga6
+ Revision: 1047665
+ rebuild (emptylog)

* Fri Aug 19 2016 luigiwalser <luigiwalser> 1.8.3-1.mga6
+ Revision: 1047097
- 1.8.3

* Sat Jun 18 2016 luigiwalser <luigiwalser> 1.8.2-2.mga6.tainted
+ Revision: 1022614
- rebuild with fix libmad

* Fri Jun 10 2016 luigiwalser <luigiwalser> 1.8.2-1.mga6.tainted
+ Revision: 1021002
- 1.8.2

* Mon May 09 2016 luigiwalser <luigiwalser> 1.8.1-2.mga6.tainted
+ Revision: 1011710
- rebuild for core

* Mon May 09 2016 luigiwalser <luigiwalser> 1.8.1-1.mga6.tainted
+ Revision: 1011416
- 1.8.1

* Fri Mar 25 2016 wally <wally> 1.8.0-1.mga6.tainted
+ Revision: 995250
- new version 1.8.0
- enable dependency tracking

* Sun Mar 20 2016 wally <wally> 1.7.91-3.mga6.tainted
+ Revision: 993093
- enable x264 build on arm again

* Sun Mar 20 2016 wally <wally> 1.7.91-2.mga6.tainted
+ Revision: 993055
- disable x264 build on arm

* Sun Mar 20 2016 wally <wally> 1.7.91-1.mga6.tainted
+ Revision: 993047
- new version 1.7.91

* Fri Mar 04 2016 wally <wally> 1.7.90-1.mga6.tainted
+ Revision: 985636
- new version 1.7.90
- mpg123 plugin was moved from -bad to -ugly

* Sat Jan 23 2016 luigiwalser <luigiwalser> 1.6.3-1.mga6.tainted
+ Revision: 926693
- 1.6.3

* Mon Jan 18 2016 luigiwalser <luigiwalser> 1.6.2-2.mga6.tainted
+ Revision: 925616
- rebuild for x264

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1.6.2-1.mga6
+ Revision: 918905
- 1.6.2

* Thu Jul 16 2015 sander85 <sander85> 1.4.5-2.mga6.tainted
+ Revision: 854703
- Rebuild for new libcdio

* Sun Jun 21 2015 luigiwalser <luigiwalser> 1.4.5-1.mga6.tainted
+ Revision: 836951
- 1.4.5

* Wed Oct 15 2014 umeabot <umeabot> 1.4.3-2.mga5.tainted
+ Revision: 739028
- Second Mageia 5 Mass Rebuild

* Sun Sep 28 2014 wally <wally> 1.4.3-1.mga5.tainted
+ Revision: 731374
- new version 1.4.3

* Tue Sep 16 2014 umeabot <umeabot> 1.4.1-2.mga5.tainted
+ Revision: 679987
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 luigiwalser <luigiwalser> 1.4.1-1.mga5.tainted
+ Revision: 674302
- 1.4.1

* Mon Jul 21 2014 fwang <fwang> 1.4.0-1.mga5.tainted
+ Revision: 654958
- drop unused doc files
- disable gtk-doc
- 1.4.0

* Sat Apr 19 2014 fwang <fwang> 1.2.4-1.mga5.tainted
+ Revision: 616994
- 1.2.4

* Sun Mar 30 2014 daviddavid <daviddavid> 1.2.3-4.mga5.tainted
+ Revision: 610548
- rebuild for new x264

* Mon Feb 17 2014 luigiwalser <luigiwalser> 1.2.3-3.mga5
+ Revision: 593271
- rebuild for x264

* Sat Feb 15 2014 luigiwalser <luigiwalser> 1.2.3-2.mga5.tainted
+ Revision: 592239
- rebuild for libcdio

* Sun Feb 09 2014 fwang <fwang> 1.2.3-1.mga5.tainted
+ Revision: 587313
- 1.2.3

* Thu Jan 23 2014 gw666 <gw666> 1.2.2-1.mga4.tainted
+ Revision: 567578
- new version (bug #12142)

* Mon Oct 21 2013 umeabot <umeabot> 1.2.0-2.mga4.tainted
+ Revision: 536917
- Mageia 4 Mass Rebuild

* Wed Sep 25 2013 fwang <fwang> 1.2.0-1.mga4.tainted
+ Revision: 485818
- new version 1.2.0

* Sat Sep 21 2013 fwang <fwang> 1.1.90-1.mga4.tainted
+ Revision: 483067
- new version 1.1.90

* Sun Sep 01 2013 fwang <fwang> 1.0.10-2.mga4.tainted
+ Revision: 473963
- rebuild for new libcdio

* Thu Aug 29 2013 fwang <fwang> 1.0.10-1.mga4.tainted
+ Revision: 472796
- new version 1.0.10

* Sat Aug 24 2013 luigiwalser <luigiwalser> 1.0.9-2.mga4.tainted
+ Revision: 471050
- rebuild for x264

* Thu Aug 01 2013 fwang <fwang> 1.0.9-1.mga4.tainted
+ Revision: 461938
- new version 1.0.9

* Mon Jun 17 2013 luigiwalser <luigiwalser> 1.0.7-2.mga4.tainted
+ Revision: 443888
- rebuild for x264

* Fri May 24 2013 fwang <fwang> 1.0.7-1.mga4.tainted
+ Revision: 425868
- new version 1.0.7

* Sat Jan 12 2013 umeabot <umeabot> 1.0.5-2.mga3.tainted
+ Revision: 352771
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 fwang <fwang> 1.0.5-1.mga3.tainted
+ Revision: 343522
- new version 1.0.5

* Fri Dec 21 2012 cjw <cjw> 1.0.4-1.mga3.tainted
+ Revision: 333586
- 1.0.4
- better summary and description for a52dec plugin package

* Fri Nov 23 2012 fwang <fwang> 1.0.3-1.mga3.tainted
+ Revision: 321185
- new version 1.0.3

* Thu Oct 25 2012 fwang <fwang> 1.0.2-1.mga3.tainted
+ Revision: 309989
- new version 1.0.2

* Mon Oct 08 2012 fwang <fwang> 1.0.1-1.mga3.tainted
+ Revision: 303338
- new version 1.0.1

* Mon Sep 24 2012 fwang <fwang> 1.0.0-1.mga3.tainted
+ Revision: 297082
- new version 1.0.0

* Tue Sep 18 2012 fwang <fwang> 0.11.99-1.mga3.tainted
+ Revision: 295766
- new version 0.11.99

* Sat Sep 15 2012 fwang <fwang> 0.11.94-1.mga3.tainted
+ Revision: 294199
- update file list
- update file list
- imported package gstreamer1.0-plugins-ugly

